@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from InputMethodKit import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestIMKCandidates (TestCase):
     def testConstants(self):
         self.assertEqual(kIMKSingleColumnScrollingCandidatePanel, 1)
@@ -24,6 +29,10 @@ class TestIMKCandidates (TestCase):
         self.assertResultIsBOOL(IMKCandidates.dismissesAutomatically)
         self.assertArgIsBOOL(IMKCandidates.setDismissesAutomatically_, 0)
 
+    @min_os_level('10.7')
+    def testMethods10_7(self):
+        self.assertResultIsBOOL(IMKCandidates.selectCandidateWithIdentifier_)
+        
 
 if __name__ == "__main__":
     main()
